@@ -6,7 +6,7 @@ jest.mock('app/core/services/context_srv', () => ({}));
 
 describe('DashboardModel', () => {
   describe('when creating new dashboard model defaults only', () => {
-    let model;
+    let model: DashboardModel;
 
     beforeEach(() => {
       model = new DashboardModel({}, {});
@@ -27,7 +27,7 @@ describe('DashboardModel', () => {
   });
 
   describe('when getting next panel id', () => {
-    let model;
+    let model: DashboardModel;
 
     beforeEach(() => {
       model = new DashboardModel({
@@ -69,7 +69,7 @@ describe('DashboardModel', () => {
   });
 
   describe('row and panel manipulation', () => {
-    let dashboard;
+    let dashboard: DashboardModel;
 
     beforeEach(() => {
       dashboard = new DashboardModel({});
@@ -112,7 +112,7 @@ describe('DashboardModel', () => {
   });
 
   describe('Given editable false dashboard', () => {
-    let model;
+    let model: DashboardModel;
 
     beforeEach(() => {
       model = new DashboardModel({ editable: false });
@@ -130,8 +130,8 @@ describe('DashboardModel', () => {
   });
 
   describe('when loading dashboard with old influxdb query schema', () => {
-    let model;
-    let target;
+    let model: DashboardModel;
+    let target: any;
 
     beforeEach(() => {
       model = new DashboardModel({
@@ -197,7 +197,7 @@ describe('DashboardModel', () => {
   });
 
   describe('when creating dashboard model with missing list for annoations or templating', () => {
-    let model;
+    let model: DashboardModel;
 
     beforeEach(() => {
       model = new DashboardModel({
@@ -222,7 +222,7 @@ describe('DashboardModel', () => {
   });
 
   describe('Formatting epoch timestamp when timezone is set as utc', () => {
-    let dashboard;
+    let dashboard: DashboardModel;
 
     beforeEach(() => {
       dashboard = new DashboardModel({ timezone: 'utc' });
@@ -242,7 +242,7 @@ describe('DashboardModel', () => {
   });
 
   describe('updateSubmenuVisibility with empty lists', () => {
-    let model;
+    let model: DashboardModel;
 
     beforeEach(() => {
       model = new DashboardModel({});
@@ -255,7 +255,7 @@ describe('DashboardModel', () => {
   });
 
   describe('updateSubmenuVisibility with annotation', () => {
-    let model;
+    let model: DashboardModel;
 
     beforeEach(() => {
       model = new DashboardModel({
@@ -272,7 +272,7 @@ describe('DashboardModel', () => {
   });
 
   describe('updateSubmenuVisibility with template var', () => {
-    let model;
+    let model: DashboardModel;
 
     beforeEach(() => {
       model = new DashboardModel({
@@ -289,7 +289,7 @@ describe('DashboardModel', () => {
   });
 
   describe('updateSubmenuVisibility with hidden template var', () => {
-    let model;
+    let model: DashboardModel;
 
     beforeEach(() => {
       model = new DashboardModel({
@@ -306,7 +306,7 @@ describe('DashboardModel', () => {
   });
 
   describe('updateSubmenuVisibility with hidden annotation toggle', () => {
-    let dashboard;
+    let dashboard: DashboardModel;
 
     beforeEach(() => {
       dashboard = new DashboardModel({
@@ -323,7 +323,7 @@ describe('DashboardModel', () => {
   });
 
   describe('When collapsing row', () => {
-    let dashboard;
+    let dashboard: DashboardModel;
 
     beforeEach(() => {
       dashboard = new DashboardModel({
@@ -365,7 +365,7 @@ describe('DashboardModel', () => {
   });
 
   describe('When expanding row', () => {
-    let dashboard;
+    let dashboard: DashboardModel;
 
     beforeEach(() => {
       dashboard = new DashboardModel({
@@ -637,7 +637,7 @@ describe('DashboardModel', () => {
   });
 
   describe('Given a dashboard with one panel legend on and two off', () => {
-    let model;
+    let model: DashboardModel;
 
     beforeEach(() => {
       const data = {
