@@ -1,8 +1,8 @@
-import { ReactPanelPlugin } from '@grafana/ui';
+import { PanelPlugin } from '@grafana/ui';
 import { PieChartPanelEditor } from './PieChartPanelEditor';
 import { PieChartPanel } from './PieChartPanel';
 import { PieChartOptions, defaults } from './types';
 
-export const reactPanel = new ReactPanelPlugin<PieChartOptions>(PieChartPanel)
+export const plugin = new PanelPlugin<PieChartOptions>(PieChartPanel)
   .setDefaults(defaults)
   .setEditor(PieChartPanelEditor);
